#include "testlib.h"
#include <iostream>
#include <system_error>
#include <csignal>

using namespace std;

using ll = long long;

int main(int argc, char* argv[])
try
{
    registerInteraction(argc, argv);

    cout.exceptions(ios_base::badbit | ios_base::failbit);

#ifdef SIGPIPE
    if (signal(SIGPIPE, SIG_IGN) == SIG_ERR)
    {
        throw std::system_error(errno, std::system_category(), "signal");
    }
#endif


    ll n = inf.readLong(2, 1000000000LL * 1000000000LL, "n"), x = inf.readLong(1, n, "x");

    cout << n << endl;

    set<ll> used_values;
    ll last_color = 0;
    int cnt = 0;

    // Store color that was queried more than once
    ll color_queried_multiple_times = 0;

    while (true)
    {
        std::string cmd = ouf.readToken("[?=]", "cmd");
        ll k = ouf.readLong(1, n, "k");

        tout << cmd << " " << k << endl;

        if (cmd == "?")
        {
            if (
                    color_queried_multiple_times == 0 // No color yet used multiple times
                    && used_values.insert(k).second == false // Queried color has already been used
               )
            {
                color_queried_multiple_times = k;
            }

            if (last_color == 0)
            {
                // Output arbitrary value deterministically
                cout << (((k >> 1) ^ n ^ (n >> 1) ^ (n >> 2)) & 1) << endl;
            }
            else
            {
                if (abs(last_color - k) < x)
                {
                    cout << 0 << endl;
                }
                else
                {
                    cout << 1 << endl;
                }
            }

            last_color = k;

            if (cnt < INT_MAX)
            {
                cnt++;
            }
        }
        else // cmd == "="
        {
            if (cnt > 64)
            {
                quitf(_wa, "Query limit exceeded");
            }
            else if (color_queried_multiple_times != 0)
            {
                quitf(_wa, "Hair color %lld was used multiple times", color_queried_multiple_times);
            }
            else if (k == x)
            {
                quitf(_ok, "OK (%d queries)", cnt);
            }
            else
            {
                quitf(_wa, "Wrong guess");
            }
        }
    }
}
catch (const std::exception& e)
{
    quit(_pe, e.what());
}
